#
# spec file for package wireguard-tools
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2020-2021, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           wireguard-tools
Version:        1.0.20210914
Release:        8.5
Summary:        WireGuard userspace tools
License:        GPL-2.0-only
Group:          Productivity/Networking/Security
URL:            https://www.wireguard.com/
Source:         https://git.zx2c4.com/wireguard-tools/snapshot/wireguard-tools-%{version}.tar.xz
Source1:        https://git.zx2c4.com/wireguard-tools/snapshot/wireguard-tools-%{version}.tar.asc
Source99:       https://www.zx2c4.com/keys/AB9942E6D4A4CFC3412620A749FC7012A5DE03AE.asc#/WireGuard.keyring
Patch1:         Support-systemd-resolved-split-dns-setup.patch
BuildRequires:  bash-completion
BuildRequires:  pkgconfig
%{?systemd_ordering}

%description
WireGuard is a novel VPN that runs inside the Linux Kernel and uses
state-of-the-art cryptography (the "Noise" protocol). It aims to be
faster, simpler, leaner, and more useful than IPSec, while avoiding
the massive headache. It intends to be considerably more performant
than OpenVPN. WireGuard is designed as a general purpose VPN for
running on embedded interfaces and super computers alike, fit for
many different circumstances. It runs over UDP.

This package contains command-line tools to interact with the
WireGuard kernel module.  Currently, it provides only a single tool:

wg: set and retrieve configuration of WireGuard interfaces

%prep
%autosetup -p1 -n wireguard-tools-%{version}

## HACK: Fixing wg-quick's DNS= directive with a hatchet
contrib/dns-hatchet/apply.sh

%build
export CFLAGS="%{optflags}"
make V=1 -C src %{?_smp_mflags}

%install
cd src
%{make_install} \
    WITH_BASHCOMPLETION=yes \
    WITH_WGQUICK=yes \
    WITH_SYSTEMDUNITS=yes

%pre
%service_add_pre wg-quick.target wg-quick@.service

%post
%service_add_post wg-quick.target wg-quick@.service

%preun
%service_del_preun wg-quick.target wg-quick@.service

%postun
%service_del_postun wg-quick.target wg-quick@.service

%files
%license COPYING
%doc README.md
%{_sysconfdir}/wireguard/
%{_bindir}/wg
%{_bindir}/wg-quick
%{_mandir}/man8/wg.8%{?ext_man}
%{_mandir}/man8/wg-quick.8%{?ext_man}
%{_datadir}/bash-completion/completions/wg
%{_datadir}/bash-completion/completions/wg-quick
%{_unitdir}/wg-quick@.service
%{_unitdir}/wg-quick.target

%changelog
* Tue Feb 20 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN
* Fri Oct 20 2023 Frederic Crozat <fcrozat@suse.com>
- Update WireGuard.keyring with latest copy from upstream.
* Wed Aug 31 2022 Dominik Heidler <dheidler@suse.de>
- Support multiple DNS search domains
  * Support-systemd-resolved-split-dns-setup.patch
* Mon Aug 15 2022 Thorsten Kukuk <kukuk@suse.com>
- Don't hard require systemd, it's not a hard dependency
* Tue Feb 22 2022 Johannes Segitz <jsegitz@suse.com>
- Drop harden_wg-quick@.service.patch. The currrent logic for setting
  DNS is fiddling massively with the system. This is currently not
  compatible with these settings (bsc#1196096)
* Thu Feb 17 2022 Dominik Heidler <dheidler@suse.de>
- Support systemd-resolved split-dns setup
  * Support-systemd-resolved-split-dns-setup.patch
* Wed Jan  5 2022 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Added patch(es):
  * harden_wg-quick@.service.patch
* Fri Oct  1 2021 Andreas Stieger <andreas.stieger@gmx.de>
- remove world-readable permissions from /etc/wireguard boo#1191224
* Sun Sep 26 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 1.0.20210914
  * no relevant changes for Linux systems
* Sun Apr 25 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 1.0.20210424
  * wg-quick: kill route monitor when loop terminates
* Mon Mar 15 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 1.0.20210315
  * Makefile: fix version indicator
  * wireguard-tools: const correctness
  * wireguard-tools: drag in headers for prototypes
  * ipc: uniformly ignore preshared keys that are zero
* Tue Feb 23 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 1.0.20210223
  * embeddable-wg-library: sync latest from netlink.h
  * completion: add help and syncconf completions
  * sticky-sockets: do not use SO_REUSEADDR
  * man: LOG_LEVEL variables changed name
  * ipc: do not use fscanf with trailing \n
  * ipc: read trailing responses after set operation
* Thu Aug 27 2020 Martin Hauke <mardnh@gmx.de>
- Udpate to version 1.0.20200827
  * wg-quick: android: use iproute2 to bring up interface instead
    of ndc
  * Revert "wg-quick: wait on process substitutions"
* Sat Aug 22 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.0.20200820
  * ipc: split into separate files per-platform
  * wincompat: fold random into genkey
  * systemd: add reload target to systemd unit
  * man: wg-quick: use syncconf instead of addconf for strip example
  * pubkey: isblank is a subset of isspace
  * ctype: use non-locale-specific ctype.h
  * wg-quick: wait on process substitutions
* Thu May 14 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.0.20200513
  * Makefile: remember to install all systemd units
  * ipc: openbsd: switch to array ioctl interface
* Mon May 11 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.0.20200510
  * ipc: add support for openbsd kernel implementation
  * ipc: cleanup openbsd support
  * wg-quick: add support for openbsd kernel implementation
  * wg-quick: cleanup openbsd support
  * wg-quick: support dns search domains
  * Makefile: simplify silent cleaning
  * git: add gitattributes so tarball doesn't have gitignore files
  * terminal: specialize color_mode to stdout only
  * highlighter: insist on 256-bit keys, not 257-bit or 258-bit
  * wg-quick: android: support application whitelist
  * systemd: add wg-quick.target
- Remove patch (not longer needed):
  * wireguard-fix-systemd-service.patch
- Remove source file (fixed upstream)
  * wireguard.target
    This functionality is now provided by wg-quick.target
* Sat Mar 21 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.0.20200319
  * netlink: initialize mostly unused field
  * curve25519: squelch warnings on clang
  * man: fix grammar in wg(8) and wg-quick(8)
  * man: backlink wg-quick(8) in wg(8)
  * man: add a warning to the SaveConfig description
  * wincompat: use string_list instead of inflatable_buffer
* Thu Feb  6 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.0.20200206
  * man: document dynamic debug trick for Linux
  * extract-{handshakes,keys}: rework for upstream kernel
  * netlink: remove libmnl requirement
  * embeddable-wg-library: use newer string_list
  * netlink: don't pretend that sysconf isn't a function
  * Small cleanups.
* Tue Jan 21 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.0.20200121
  * Makefile: add standard 'all' target
  * ipc: simplify inflatable buffer and add fuzzer
  * fuzz: add generic command argument fuzzer
  * fuzz: add set and setconf fuzzers
  * netlink: make sure to clear return value when trying again
  * Makefile: sort inputs to linker so that build is reproducible
* Mon Jan 20 2020 Martin Hauke <mardnh@gmx.de>
- Initial package, version 1.0.20200102
